@@ -59,9 +59,7 @@ MailClient::~MailClient()
 {
 }
 
-bool MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
-                               const KIdentityManagement::Identity &identity, bool bccMe,
-                               const QString &attachment, const QString &mailTransport)
+bool MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, bool bccMe, const QString &attachment, const QString &mailTransport)
 {
     KCalCore::Attendee::List attendees = incidence->attendees();
     if (attendees.isEmpty()) {
@@ -135,10 +133,8 @@ bool MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
                 bccMe, attachment, mailTransport);
 }
 
-bool MailClient::mailOrganizer(const KCalCore::IncidenceBase::Ptr &incidence,
-                               const KIdentityManagement::Identity &identity, const QString &from,
-                               bool bccMe, const QString &attachment, const QString &sub,
-                               const QString &mailTransport)
+bool MailClient::mailOrganizer(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &attachment,
+                               const QString &sub, const QString &mailTransport)
 {
     const QString to = incidence->organizer()->fullName();
     QString subject = sub;
@@ -158,10 +154,8 @@ bool MailClient::mailOrganizer(const KCalCore::IncidenceBase::Ptr &incidence,
                 bccMe, attachment, mailTransport);
 }
 
-bool MailClient::mailTo(const KCalCore::IncidenceBase::Ptr &incidence,
-                        const KIdentityManagement::Identity &identity, const QString &from,
-                        bool bccMe, const QString &recipients, const QString &attachment,
-                        const QString &mailTransport)
+bool MailClient::mailTo(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &recipients,
+                        const QString &attachment, const QString &mailTransport)
 {
     QString subject;
 
@@ -191,10 +185,8 @@ QStringList extractEmailAndNormalize(const QString &email)
     return normalizedEmail;
 }
 
-bool MailClient::send(const KIdentityManagement::Identity &identity, const QString &from,
-                      const QString &_to, const QString &cc, const QString &subject,
-                      const QString &body, bool hidden, bool bccMe, const QString &attachment,
-                      const QString &mailTransport)
+bool MailClient::send(const KIdentityManagement::Identity &identity, const QString &from, const QString &_to, const QString &cc, const QString &subject, const QString &body, bool hidden, bool bccMe,
+                      const QString &attachment, const QString &mailTransport)
 {
     Q_UNUSED(hidden);
 
@@ -233,7 +225,7 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
         qCCritical(KOALARMCLIENT_LOG) << "Error fetching transport; mailTransport"
                                       << mailTransport
                                       << MailTransport::TransportManager::self()->
-        defaultTransportName();
+            defaultTransportName();
         return false;
     }
 
